@@ -925,7 +925,7 @@ class CfsClient(AbstractClient):
 
 
     def DoDirectoryOperation(self, request):
-        r"""文件系统目录操作接口
+        r"""文件系统目录操作接口。当前仅 Turbo 系列文件系统支持调用此接口进行目录操作，通用系列文件系统（含增强型）不支持调用。
 
         :param request: Request instance for DoDirectoryOperation.
         :type request: :class:`tencentcloud.cfs.v20190719.models.DoDirectoryOperationRequest`
